<?php
// +----------------------------------------------------------------------
// | JDCMS V2.0
// +----------------------------------------------------------------------
// | CREATE BY 合肥几度互联网络科技有限公司(http://www.ji-du.com.cn)
// +----------------------------------------------------------------------
namespace app\admin\model;

use think\exception\PDOException;
use think\Model;
use app\admin\model\Content;
use app\admin\model\DiyModel;

class Category extends Model
{
	protected $name = 'category';

	private $sysfield = ['app','caches','config','data','system','template','uploads','list','common','base'];

	public function getAll()
	{
		return $this->alias('a')->join('auth_model b', 'a.mid=b.id')->field('a.*, b.name')->order('a.rank asc')->select();
	}

	public function getAllCategory()
    {
        $item = $this->select();
        $product = empty($item)?array():$item->toArray();
        return $product;
    }

	public function insertCategory($param)
    {
        try {
			if ($param['title'] == '') {
				return ['status'=>-1, 'msg'=>'模板名称不能为空'];
			}
			
            if ($param['tag'] == '') {
				$param['tag'] = get_pinyin(iconv('utf-8', 'gb2312//ignore', $param['title']), 0);
			}
			
			if (!preg_match("/^[A-Za-z0-9_]+$/", $param['tag'])) {
				return ['status'=>-1, 'msg'=>'分类名称只能由英文字母数字和下划线组成'];
			}
        
            if (in_array($param['tag'], $this->sysfield)) {
                return ['status'=>-1, 'msg' => "分类别名不能为系统关键字，关键字列表：".implode(' , ', $this->sysfield)];
			}

			$param['status'] = $param['status'] == 'off' ? 2 : 1;	// 1 显示，2 不显示，默认显示
			$param['target'] = $param['target'] == 'on' ? 1 : 2;	// 1 新窗口打开，2 原窗口打开，默认原窗口打开

			$result = $this->allowField(true)->save($param);
			
			return $result ? ['status'=>1, 'msg'=>OK] : ['status'=>0, 'msg'=>$this->getError()];
        } catch (PDOException $e) {
            return ['status'=>-2, 'msg'=>$e->getMessage()];
        }
	}

	public function insertAllCategory($param)
	{
		try	{
			if (!isset($param['title'])) {
				return ['status'=>-1, 'msg'=>'至少添加一个模板'];
			}
		
			$titles = $param['title'];
			$data = [];
			foreach ($titles as $val) {
				if ($val != '') {
					$data[] = ['title'=>$val];
				}
			}

			if (count($data) == 0) {
				return ['status'=>-1, 'msg'=>'至少添加一个模板'];
			}

			foreach ($data as $key => $val) {
				$data[$key]['tag']		 = get_pinyin(iconv('utf-8', 'gb2312//ignore', $val['title']), 0);
				$data[$key]['pid']		 = $param['pid'];
				$data[$key]['is_cover']  = $param['is_cover'];
				$data[$key]['mid'] 		 = $param['mid'];
				$data[$key]['tpl_cover'] = $param['tpl_cover'];
				$data[$key]['tpl_list']  = $param['tpl_list'];
				$data[$key]['tpl_detail']= $param['tpl_detail'];
				$data[$key]['nav']		 = 2;
			}

			$res = $this->saveAll($data);
			
			return $res ? ['status'=>1, 'msg'=>OK] : ['status'=>0, 'msg'=>$this->getError()]; 
		} catch (PDOException $e) {
			return ['status'=>-2, 'msg'=>$e->getMessage()];
		}
	}
	
	public function updateCategory($param, $id)
	{
		try{
			if ($param['title'] == '') {
				return ['status'=>-1, 'msg'=>'模板名称不能为空'];
			}
			
            if ($param['tag'] == '') {
                $param['tag'] = get_pinyin(iconv('utf-8', 'gb2312//ignore', $param['title']), 0);
			}
			
			if (!preg_match("/^[A-Za-z0-9_]+$/", $param['tag'])) {
				return ['status'=>-1, 'msg'=>'分类名称只能由英文字母数字和下划线组成'];
			}
        
            if (in_array($param['tag'], $this->sysfield)) {
                return ['status'=>-1, 'msg' => "分类别名不能为系统关键字，关键字列表：".implode(' , ', $this->sysfield)];
			}

			$param['status'] = $param['status'] == 'off' ? 2 : 1;	// 1 显示，2 不显示，默认显示
			$param['target'] = $param['target'] == 'on' ? 1 : 2;	// 1 新窗口打开，2 原窗口打开，默认原窗口打开

            $find = $this->where('id', $id)->find();
            // 模型改变，对应的数据表也会改变，将原来的数据全部删除
            if ($find['mid'] != $param['mid']) {
                $content_model = new Content;
                $the_ids = $content_model->where('cid', $find['id'])->column('the_id');

                if ($the_ids) {
                    // $content_model->where('cid', $find['id'])->update(['mid'=>$param['mid'], 'the_id'=>0]);
                    $content_model->where('cid', $find['id'])->delete();
                    $diymodel_model = new DiyModel;
                    $find_table = $diymodel_model->where('id', $find['mid'])->value('table_name');
                    if ($find_table) {
                        db('diy_'.$find_table)->where('id', 'in', $the_ids)->delete();
                    }
                }
            }

            $result = $this->allowField(true)->save($param, ['id'=>$id]);
			
			return $result ? ['status'=>1, 'msg'=>OK] : ['status'=>0, 'msg'=>$this->getError()];
        } catch (PDOException $e) {
            return ['status'=>-2, 'msg'=>$e->getMessage()];
        }
	}

	public function getChildId( $pid, $father=0)
	{
        $cat = $this->all();
		$arr = [];
		if ($father == 1) {
            $arr = intval($pid);
        }
        foreach ($cat as $v) {
            if ($v['pid'] == $pid) {
                $arr[] = $v['id'];
                $arr = array_merge($arr, $this->getChildId($v['id']));
            }
        }
        return $arr;
	}

}